@@ -1,6 +1,6 @@
 package RT::Authen::ExternalAuth;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 =head1 NAME
 
@@ -216,7 +216,7 @@ For example, an LDAP mapping might look like:
     # Use the below LDAP source for both authentication, as well as user
     # information
     Set( $ExternalAuthPriority, ["My_LDAP"] );
-    Set( $ExternalAuthInfo,     ["My_LDAP"] );
+    Set( $ExternalInfoPriority, ["My_LDAP"] );
 
     # Users created from LDAP should be Privileged; this is a core RT
     # option.  Additionally, this is the 4.2 name for the option; for RT
@@ -294,122 +294,175 @@ use RT::Authen::ExternalAuth::DBI;
 
 use strict;
 
-# Ensure passwords are obfuscated on the System Configuration page
-$RT::Config::META{ExternalSettings}->{Obfuscate} = sub {
-    my ($config, $sources, $user) = @_;
+$RT::Config::META{ExternalSettings} = {
+    Obfuscate => sub {
+        # Ensure passwords are obfuscated on the System Configuration page
+        my ($config, $sources, $user) = @_;
 
-    # XXX $user is never passed from RT as of 4.0.5 :(
-    my $msg = 'Password not printed';
-       $msg = $user->loc($msg) if $user and $user->Id;
+        # $user is only passed in versions of RT with 3c7db050
+        my $msg = 'Password not printed';
+           $msg = $user->loc($msg) if $user and $user->Id;
 
-    for my $source (values %$sources) {
-        $source->{pass} = $msg;
-    }
-    return $sources;
+        for my $source (values %$sources) {
+            $source->{pass} = $msg;
+        }
+        return $sources;
+    },
+    PostLoadCheck => sub {
+        my $self = shift;
+        my $settings = shift || {};
+
+        my $remove = sub {
+            my ($service) = @_;
+            delete $settings->{$service};
+
+            $self->Set( 'ExternalAuthPriority',
+                        [ grep { $_ ne $service } @{ $self->Get('ExternalAuthPriority') || [] } ] );
+
+            $self->Set( 'ExternalInfoPriority',
+                        [ grep { $_ ne $service } @{ $self->Get('ExternalInfoPriority') || [] } ] );
+        };
+
+        for my $service (keys %$settings) {
+            my %conf = %{ $settings->{$service} };
+
+            if ($conf{type} !~ /^(ldap|db|cookie)$/) {
+                $RT::Logger->error(
+                    "Service '$service' in ExternalInfoPriority is not ldap, db, or cookie; removing."
+                );
+                $remove->($service);
+                next;
+            }
+
+            next unless $conf{type} eq 'db';
+
+            # Ensure people don't misconfigure DBI auth to point to RT's
+            # Users table; only check server/hostname/table, as
+            # user/pass might be different (root, for instance)
+            no warnings 'uninitialized';
+            next unless lc $conf{server} eq lc RT->Config->Get('DatabaseHost') and
+                        lc $conf{database} eq lc RT->Config->Get('DatabaseName') and
+                        lc $conf{table} eq 'users';
+
+            $RT::Logger->error(
+                "RT::Authen::ExternalAuth should _not_ be configured with a database auth service ".
+                "that points back to RT's internal Users table.  Removing the service '$service'! ".
+                "Please remove it from your config file."
+            );
+
+            $remove->($service);
+        }
+        $self->Set( 'ExternalSettings', $settings );
+    },
+};
+
+$RT::Config::META{ExternalAuthPriority} = {
+    PostLoadCheck => sub {
+        my $self = shift;
+        my @values = @{ shift || [] };
+        if (not @values) {
+            $self->Set( 'ExternalAuthPriority', \@values );
+            return;
+        }
+
+        my %settings = %{ $self->Get('ExternalSettings') };
+        for my $key (grep {not $settings{$_}} @values) {
+            $RT::Logger->error("Removing '$key' from ExternalAuthPriority, as it is not defined in ExternalSettings");
+        }
+        @values = grep {$settings{$_}} @values;
+        $self->Set( 'ExternalAuthPriority', \@values );
+    },
+};
+
+$RT::Config::META{ExternalInfoPriority} = {
+    PostLoadCheck => sub {
+        my $self = shift;
+        my @values = @{ shift || [] };
+        if (not @values) {
+            $RT::Logger->debug("ExternalInfoPriority not defined. User information (including user enabled/disabled) cannot be externally-sourced");
+            $self->Set( 'ExternalInfoPriority', \@values );
+            return;
+        }
+
+        my %settings = %{ $self->Get('ExternalSettings') };
+        for my $key (grep {not $settings{$_}} @values) {
+            $RT::Logger->error("Removing '$key' from ExternalInfoPriority, as it is not defined in ExternalSettings");
+        }
+        @values = grep {$settings{$_}} @values;
+
+        for my $key (grep {$settings{$_}{type} eq "cookie"} @values) {
+            $RT::Logger->error("Removing '$key' from ExternalInfoPriority, as cookie authentication cannot be used as an information source");
+        }
+        @values = grep {$settings{$_}{type} ne "cookie"} @values;
+
+        $self->Set( 'ExternalInfoPriority', \@values );
+    },
 };
 
 sub DoAuth {
     my ($session,$given_user,$given_pass) = @_;
 
-    unless(defined($RT::ExternalAuthPriority)) {
-        return (0, "ExternalAuthPriority not defined, please check your configuration file.");
-    }
+    # Get the prioritised list of external authentication services
+    my @auth_services = @{ RT->Config->Get('ExternalAuthPriority') };
+    my $settings = RT->Config->Get('ExternalSettings');
 
-    my $no_info_check = 0;
-    unless(defined($RT::ExternalInfoPriority)) {
-        $RT::Logger->debug("ExternalInfoPriority not defined. User information (including user enabled/disabled cannot be externally-sourced");
-        $no_info_check = 1;
-    }
-
-    # Ensure people don't misconfigure DBI auth to point to RT's Users table
-    for my $service (keys %$RT::ExternalSettings) {
-        my %conf = %{ $RT::ExternalSettings->{$service} };
-        next unless $conf{type} eq 'db';
-
-        # user/pass might be different (root, for instance)
-        no warnings 'uninitialized';
-        next unless lc $conf{server} eq lc $RT::DatabaseHost and
-                    lc $conf{database} eq lc $RT::DatabaseName and
-                    lc $conf{table} eq 'users';
-
-        $RT::Logger->error(
-            "RT::Authen::ExternalAuth should _not_ be configured with a database auth service ".
-            "that points back to RT's internal Users table.  Removing the service '$service'! ".
-            "Please remove it from your config file."
-        );
-
-        # Remove it!
-        delete $RT::ExternalSettings->{$service};
-
-        @$RT::ExternalAuthPriority = grep { $_ ne $service } @$RT::ExternalAuthPriority
-            if $RT::ExternalAuthPriority;
-
-        @$RT::ExternalInfoPriority = grep { $_ ne $service } @$RT::ExternalInfoPriority
-            if $RT::ExternalInfoPriority;
-    }
+    return (0, "ExternalAuthPriority not defined, please check your configuration file.")
+        unless @auth_services;
 
     # This may be used by single sign-on (SSO) authentication mechanisms for bypassing a password check.
-    my $pass_bypass = 0;
     my $success = 0;
 
     # Should have checked if user is already logged in before calling this function,
     # but just in case, we'll check too.
     return (0, "User already logged in!") if ($session->{'CurrentUser'} && $session->{'CurrentUser'}->Id);
-    # We don't have a logged in user. Let's try all our available methods in order.
-    # last if success, next if not.
-    
-    # Get the prioritised list of external authentication services
-    my @auth_services = @$RT::ExternalAuthPriority;
-    
+
     # For each of those services..
     foreach my $service (@auth_services) {
 
-	$pass_bypass = 0;
-
         # Get the full configuration for that service as a hashref
-        my $config = $RT::ExternalSettings->{$service};
+        my $config = $settings->{$service};
         $RT::Logger->debug( "Attempting to use external auth service:",
                             $service);
 
         # $username will be the final username we decide to check
         # This will not necessarily be $given_user
         my $username = undef;
-        
+
         #############################################################
         ####################### SSO Check ###########################
         #############################################################
-        if ($config->{'type'} eq 'cookie') {    
+        if ($config->{'type'} eq 'cookie') {
             # Currently, Cookie authentication is our only SSO method
             $username = RT::Authen::ExternalAuth::DBI::GetCookieAuth($config);
         }
         #############################################################
-        
+
         # If $username is defined, we have a good SSO $username and can
         # safely bypass the password checking later on; primarily because
         # it's VERY unlikely we even have a password to check if an SSO succeeded.
-        $pass_bypass = 0;
-	if(defined($username)) {
-	    $RT::Logger->debug("Pass not going to be checked, attempting SSO");
+        my $pass_bypass = 0;
+        if(defined($username)) {
+            $RT::Logger->debug("Pass not going to be checked, attempting SSO");
             $pass_bypass = 1;
         } else {
 
-	    # SSO failed and no $user was passed for a login attempt
-	    # We only don't return here because the next iteration could be an SSO attempt
-	    unless(defined($given_user)) {
-	    	$RT::Logger->debug("SSO Failed and no user to test with. Nexting");
-		next;
-	    }
+            # SSO failed and no $user was passed for a login attempt
+            # We only don't return here because the next iteration could be an SSO attempt
+            unless(defined($given_user)) {
+                $RT::Logger->debug("SSO Failed and no user to test with. Nexting");
+                next;
+            }
 
             # We don't have an SSO login, so we will be using the credentials given
             # on RT's login page to do our authentication.
             $username = $given_user;
-    
+
             # Don't continue unless the service works.
-	    # next unless RT::Authen::ExternalAuth::TestConnection($config);
+            # next unless RT::Authen::ExternalAuth::TestConnection($config);
 
             # Don't continue unless the $username exists in the external service
 
-	    $RT::Logger->debug("Calling UserExists with \$username ($username) and \$service ($service)");
+            $RT::Logger->debug("Calling UserExists with \$username ($username) and \$service ($service)");
             next unless RT::Authen::ExternalAuth::UserExists($username, $service);
         }
 
@@ -426,12 +479,14 @@ sub DoAuth {
 
         # Unless we have loaded a valid user with a UserID create one.
         unless ($session->{'CurrentUser'}->Id) {
-			my $UserObj = RT::User->new($RT::SystemUser);
-        	my ($val, $msg) = 
-              $UserObj->Create(%{ref($RT::AutoCreate) ? $RT::AutoCreate : {}},
-                               Name   => $username,
-                               Gecos  => $username,
-                              );
+            my $UserObj = RT::User->new($RT::SystemUser);
+            my $create = RT->Config->Get('UserAutocreateDefaultsOnLogin')
+                || RT->Config->Get('AutoCreate');
+            my ($val, $msg) =
+                $UserObj->Create(%{ref($create) ? $create : {}},
+                                 Name   => $username,
+                                 Gecos  => $username,
+                             );
             unless ($val) {
                 $RT::Logger->error( "Couldn't create user $username: $msg" );
                 next;
@@ -441,13 +496,13 @@ sub DoAuth {
                                 "(",
                                 $UserObj->Id,
                                 ")");
-            
+
             $RT::Logger->debug("Loading new user (",
-            					$username,
-            					") into current session");
+                                                $username,
+                                                ") into current session");
             $session->{'CurrentUser'}->Load($username);
-        } 
-        
+        }
+
         ####################################################################
         ########## Authentication ##########################################
         ####################################################################
@@ -455,21 +510,21 @@ sub DoAuth {
         # succeeded. If we didn't then, success is determined by a password
         # test.
         $success = 0;
-	if($pass_bypass) {
+        if($pass_bypass) {
             $RT::Logger->debug("Password check bypassed due to SSO method being in use");
             $success = 1;
         } else {
             $RT::Logger->debug("Password validation required for service - Executing...");
             $success = RT::Authen::ExternalAuth::GetAuth($service,$username,$given_pass);
         }
-       
+
         $RT::Logger->debug("Password Validation Check Result: ",$success);
 
         # If the password check succeeded then this is our authoritative service
         # and we proceed to user information update and login.
         last if $success;
     }
-    
+
     # If we got here and don't have a user loaded we must have failed to
     # get a full, valid user from an authoritative external source.
     unless ($session->{'CurrentUser'} && $session->{'CurrentUser'}->Id) {
@@ -479,37 +534,37 @@ sub DoAuth {
 
     unless($success) {
         $session->{'CurrentUser'} = RT::CurrentUser->new;
-	return (0, "Password Invalid");
+        return (0, "Password Invalid");
     }
-    
+
     # Otherwise we succeeded.
     $RT::Logger->debug("Authentication successful. Now updating user information and attempting login.");
-        
+
     ####################################################################################################
     ############################### The following is auth-method agnostic ##############################
     ####################################################################################################
-    
+
     # If we STILL have a completely valid RT user to play with...
     # and therefore password has been validated...
     if ($session->{'CurrentUser'} && $session->{'CurrentUser'}->Id) {
-        
+
         # Even if we have JUST created the user in RT, we are going to
         # reload their information from an external source. This allows us
         # to be sure that the user the cookie gave us really does exist in
-        # the database, but more importantly, UpdateFromExternal will check 
-        # whether the user is disabled or not which we have not been able to 
+        # the database, but more importantly, UpdateFromExternal will check
+        # whether the user is disabled or not which we have not been able to
         # do during auto-create
 
-	# These are not currently used, but may be used in the future.
-	my $info_updated = 0;
-	my $info_updated_msg = "User info not updated";
+        # These are not currently used, but may be used in the future.
+        my $info_updated = 0;
+        my $info_updated_msg = "User info not updated";
 
-        unless($no_info_check) {
+        if ( @{ RT->Config->Get('ExternalInfoPriority') } ) {
             # Note that UpdateUserInfo does not care how we authenticated the user
             # It will look up user info from whatever is specified in $RT::ExternalInfoPriority
             ($info_updated,$info_updated_msg) = RT::Authen::ExternalAuth::UpdateUserInfo($session->{'CurrentUser'}->Name);
         }
-                
+
         # Now that we definitely have up-to-date user information,
         # if the user is disabled, kick them out. Now!
         if ($session->{'CurrentUser'}->UserObj->Disabled) {
@@ -517,12 +572,12 @@ sub DoAuth {
             return (0, "User account disabled, login denied");
         }
     }
-    
+
     # If we **STILL** have a full user and the session hasn't already been deleted
     # This If/Else is logically unnecessary, but it doesn't hurt to leave it here
     # just in case. Especially to be a double-check to future modifications.
     if ($session->{'CurrentUser'} && $session->{'CurrentUser'}->Id) {
-            
+
             $RT::Logger->info(  "Successful login for",
                                 $session->{'CurrentUser'}->Name,
                                 "from",
@@ -537,10 +592,10 @@ sub DoAuth {
             # Make SURE the session is purged to an empty user.
             $session->{'CurrentUser'} = RT::CurrentUser->new;
             return (0, "Failed to authenticate externally");
-            # This will cause autohandler to request IsPassword 
+            # This will cause autohandler to request IsPassword
             # which will in turn call IsExternalPassword
     }
-    
+
     return (1, "Successful login");
 }
 
@@ -552,18 +607,18 @@ sub UpdateUserInfo {
     my $updated         = 0;
     my $msg             = "User NOT updated";
 
-    my $user_disabled 	= RT::Authen::ExternalAuth::UserDisabled($username);
+    my $user_disabled   = RT::Authen::ExternalAuth::UserDisabled($username);
 
-    my $UserObj = RT::User->new($RT::SystemUser);
-    $UserObj->Load($username);        
+    my $UserObj = RT::User->new(RT->SystemUser);
+    $UserObj->Load($username);
 
     # If user is disabled, set the RT::Principal to disabled and return out of the function.
     # I think it's a waste of time and energy to update a user's information if they are disabled
-    # and it could be a security risk if they've updated their external information with some 
-    # carefully concocted code to try to break RT - worst case scenario, but they have been 
+    # and it could be a security risk if they've updated their external information with some
+    # carefully concocted code to try to break RT - worst case scenario, but they have been
     # denied access after all, don't take any chances.
-     
-    # If someone gives me a good enough reason to do it, 
+
+    # If someone gives me a good enough reason to do it,
     # then I'll update all the info for disabled users
 
     if ($user_disabled) {
@@ -573,14 +628,14 @@ sub UpdateUserInfo {
             # Log what has happened
             $RT::Logger->info("User marked as DISABLED (",
                                 $username,
-                                ") per External Service", 
+                                ") per External Service",
                                 "($val, $message)\n");
             $msg = "User Disabled";
         }
 
         return ($updated, $msg);
-    }    
-        
+    }
+
     # Make sure principal is not disabled in RT
     if ( $UserObj->Disabled ) {
         my ($val, $message) = $UserObj->SetDisabled(0);
@@ -623,27 +678,25 @@ sub GetAuth {
 
     # Request a username/password check from the specified service
     # This is only valid for non-SSO services.
-    
+
     my ($service,$username,$password) = @_;
-    
+
     my $success = 0;
-    
+
     # Get the full configuration for that service as a hashref
-    my $config = $RT::ExternalSettings->{$service};
-    
+    my $config = RT->Config->Get('ExternalSettings')->{$service};
+
     # And then act accordingly depending on what type of service it is.
     # Right now, there is only code for DBI and LDAP non-SSO services
-    if ($config->{'type'} eq 'db') {    
+    if ($config->{'type'} eq 'db') {
         $success = RT::Authen::ExternalAuth::DBI::GetAuth($service,$username,$password);
-	$RT::Logger->debug("DBI password validation result:",$success);
+        $RT::Logger->debug("DBI password validation result:",$success);
     } elsif ($config->{'type'} eq 'ldap') {
         $success = RT::Authen::ExternalAuth::LDAP::GetAuth($service,$username,$password);
-	$RT::Logger->debug("LDAP password validation result:",$success);
-    } else {
-        $RT::Logger->error("Invalid service type for GetAuth:",$service);
+        $RT::Logger->debug("LDAP password validation result:",$success);
     }
-    
-    return $success; 
+
+    return $success;
 }
 
 sub UserExists {
@@ -656,7 +709,7 @@ sub UserExists {
     my $success = 0;
 
     # Get the full configuration for that service as a hashref
-    my $config = $RT::ExternalSettings->{$service};
+    my $config = RT->Config->Get('ExternalSettings')->{$service};
 
     # And then act accordingly depending on what type of service it is.
     # Right now, there is only code for DBI and LDAP non-SSO services
@@ -664,19 +717,17 @@ sub UserExists {
         $success = RT::Authen::ExternalAuth::DBI::UserExists($username,$service);
     } elsif ($config->{'type'} eq 'ldap') {
         $success = RT::Authen::ExternalAuth::LDAP::UserExists($username,$service);
-    } else {
-        $RT::Logger->debug("Invalid service type for UserExists:",$service);
     }
 
     return $success;
 }
 
 sub UserDisabled {
-    
+
     my $username = shift;
     my $user_disabled = 0;
-    
-    my @info_services = $RT::ExternalInfoPriority ? @{$RT::ExternalInfoPriority} : ();
+
+    my @info_services = @{ RT->Config->Get('ExternalInfoPriority') };
 
     # For each named service in the list
     # Check to see if the user is found in the external service
@@ -684,21 +735,13 @@ sub UserDisabled {
     # If found, check to see if user is considered disabled by the service
     # Then update the user's info in RT and return
     foreach my $service (@info_services) {
-        
-        # Get the external config for this service as a hashref        
-        my $config = $RT::ExternalSettings->{$service};
-        
-        # If the config doesn't exist, don't bother doing anything, skip to next in list.
-        unless(defined($config)) {
-            $RT::Logger->debug("You haven't defined a configuration for the service named \"",
-                                $service,
-                                "\" so I'm not going to try to get user information from it. Skipping...");
-            next;
-        }
-        
+
+        # Get the external config for this service as a hashref
+        my $config = RT->Config->Get('ExternalSettings')->{$service};
+
         # If it's a DBI config:
         if ($config->{'type'} eq 'db') {
-            
+
             unless(RT::Authen::ExternalAuth::DBI::UserExists($username,$service)) {
                 $RT::Logger->debug("User (",
                                     $username,
@@ -708,9 +751,9 @@ sub UserDisabled {
                 next;
             }
             $user_disabled = RT::Authen::ExternalAuth::DBI::UserDisabled($username,$service);
-            
+
         } elsif ($config->{'type'} eq 'ldap') {
-            
+
             unless(RT::Authen::ExternalAuth::LDAP::UserExists($username,$service)) {
                 $RT::Logger->debug("User (",
                                     $username,
@@ -720,59 +763,46 @@ sub UserDisabled {
                 next;
             }
             $user_disabled = RT::Authen::ExternalAuth::LDAP::UserDisabled($username,$service);
-                    
-        } elsif ($config->{'type'} eq 'cookie') {
-            RT::Logger->error("You cannot use SSO Cookies as an information service.");
-            next;
-        } else {
-            # The type of external service doesn't currently have any methods associated with it. Or it's a typo.
-            RT::Logger->error("Invalid type specification for config %config->{'name'}");
-            # Drop out to next service in list
-            next;
+
         }
-    
+
     }
     return $user_disabled;
 }
 
 sub CanonicalizeUserInfo {
-    
+
     # Careful, this $args hashref was given to RT::User::CanonicalizeUserInfo and
     # then transparently passed on to this function. The whole purpose is to update
     # the original hash as whatever passed it to RT::User is expecting to continue its
     # code with an update args hash.
-    
+
     my $UserObj = shift;
     my $args    = shift;
-    
+
     my $found   = 0;
     my %params  = (Name         => undef,
                   EmailAddress => undef,
                   RealName     => undef);
-    
-    $RT::Logger->debug( (caller(0))[3], 
-                        "called by", 
-                        caller, 
-                        "with:", 
+
+    $RT::Logger->debug( (caller(0))[3],
+                        "called by",
+                        caller,
+                        "with:",
                         join(", ", map {sprintf("%s: %s", $_, ($args->{$_} ? $args->{$_} : ''))}
                             sort(keys(%$args))));
 
     # Get the list of defined external services
-    my @info_services = $RT::ExternalInfoPriority ? @{$RT::ExternalInfoPriority} : undef;
+    my @info_services = @{ RT->Config->Get('ExternalInfoPriority') };
     # For each external service...
     foreach my $service (@info_services) {
-        
+
         $RT::Logger->debug( "Attempting to get user info using this external service:",
                             $service);
-        
+
         # Get the config for the service so that we know what attrs we can canonicalize
-        my $config = $RT::ExternalSettings->{$service};
-        
-        if($config->{'type'} eq 'cookie'){
-            $RT::Logger->debug("You cannot use SSO cookies as an information service!");
-            next;
-        }  
-        
+        my $config = RT->Config->Get('ExternalSettings')->{$service};
+
         # For each attr we've been told to canonicalize in the match list
         foreach my $rt_attr (@{$config->{'attr_match_list'}}) {
             # Jump to the next attr in $args if this one isn't in the attr_match_list
@@ -785,11 +815,11 @@ sub CanonicalizeUserInfo {
                                     ")");
                 next;
             }
-                               
-            # Else, use it as a canonicalization key and lookup the user info    
+
+            # Else, use it as a canonicalization key and lookup the user info
             my $key = $config->{'attr_map'}->{$rt_attr};
             my $value = $args->{$rt_attr};
-            
+
             # Check to see that the key being asked for is defined in the config's attr_map
             my $valid = 0;
             my ($attr_key, $attr_value);
@@ -805,51 +835,46 @@ sub CanonicalizeUserInfo {
                                     ")");
                 next;
             }
-            
-            # Use an if/elsif structure to do a lookup with any custom code needed 
+
+            # Use an if/elsif structure to do a lookup with any custom code needed
             # for any given type of external service, or die if no code exists for
             # the service requested.
-            
-            if($config->{'type'} eq 'ldap'){    
+
+            if($config->{'type'} eq 'ldap'){
                 ($found, %params) = RT::Authen::ExternalAuth::LDAP::CanonicalizeUserInfo($service,$key,$value);
             } elsif ($config->{'type'} eq 'db') {
                 ($found, %params) = RT::Authen::ExternalAuth::DBI::CanonicalizeUserInfo($service,$key,$value);
-            } else {
-                $RT::Logger->debug( (caller(0))[3],
-                                    "does not consider",
-                                    $service,
-                                    "a valid information service");
             }
-       
+
             # Don't Check any more attributes
             last if $found;
         }
         # Don't Check any more services
         last if $found;
     }
-    
-    # If found, Canonicalize Email Address and 
+
+    # If found, Canonicalize Email Address and
     # update the args hash that we were given the hashref for
     if ($found) {
         # It's important that we always have a canonical email address
         if ($params{'EmailAddress'}) {
             $params{'EmailAddress'} = $UserObj->CanonicalizeEmailAddress($params{'EmailAddress'});
-        } 
+        }
         %$args = (%$args, %params);
     }
 
-    $RT::Logger->info(  (caller(0))[3], 
-                        "returning", 
+    $RT::Logger->info(  (caller(0))[3],
+                        "returning",
                         join(", ", map {sprintf("%s: %s", $_, ($args->{$_} ? $args->{$_} : ''))}
                             sort(keys(%$args))));
 
     ### HACK: The config var below is to overcome the (IMO) bug in
     ### RT::User::Create() which expects this function to always
     ### return true or rejects the user for creation. This should be
-    ### a different config var (CreateUncanonicalizedUsers) and 
+    ### a different config var (CreateUncanonicalizedUsers) and
     ### should be honored in RT::User::Create()
-    return($found || $RT::AutoCreateNonExternalUsers);
-   
+    return($found || RT->Config->Get('AutoCreateNonExternalUsers'));
+
 }
 
 {
