@@ -32,8 +32,7 @@ Provides the LDAP implementation for L<RT::Authen::ExternalAuth>.
             'group'                     =>  'GROUP_NAME',
             'group_attr'                =>  'GROUP_ATTR',
 
-            'tls'                       =>  0,
-            'ssl_version'               =>  3,
+            'tls'                       =>  { verify => "require", capath => "/path/to/ca.pem" },
 
             'net_ldap_args'             => [    version =>  3   ],
 
@@ -129,11 +128,14 @@ group_attr above? Optional; defaults to C<dn>.
 
 =item tls
 
-Should we try to use TLS to encrypt connections?
+Should we try to use TLS to encrypt connections?  Either a scalar, for
+simple enabling, or a hash of values to pass to L<Net::LDAP/start_tls>.
+By default, L<Net::LDAP> does B<no> certificate validation!  To validate
+certificates, pass:
 
-=item ssl_version
-
-SSL Version to provide to Net::SSLeay *if* using SSL.
+    tls => { verify => 'require',
+             cafile => "/etc/ssl/certs/ca.pem",  # Path CA file
+           },
 
 =item net_ldap_args
 
@@ -144,10 +146,10 @@ What other args should be passed to Net::LDAP->new($host,@args)?
 =cut
 
 sub GetAuth {
-    
+
     my ($service, $username, $password) = @_;
-    
-    my $config = $RT::ExternalSettings->{$service};
+
+    my $config = RT->Config->Get('ExternalSettings')->{$service};
     $RT::Logger->debug( "Trying external auth service:",$service);
 
     my $base            = $config->{'base'};
@@ -166,27 +168,27 @@ sub GetAuth {
     # Empty parentheses as filters cause Net::LDAP to barf.
     # We take care of this by using Net::LDAP::Filter, but
     # there's no harm in fixing this right now.
-    if ($filter eq "()") { undef($filter) };
+    undef $filter if defined $filter and $filter eq "()";
 
     # Now let's get connected
     my $ldap = _GetBoundLdapObj($config);
     return 0 unless ($ldap);
 
-    $filter = Net::LDAP::Filter->new(   '(&(' . 
-                                        $attr_map->{'Name'} . 
-                                        '=' . 
-                                        escape_filter_value($username) . 
-                                        ')' . 
-                                        $filter . 
+    $filter = Net::LDAP::Filter->new(   '(&(' .
+                                        $attr_map->{'Name'} .
+                                        '=' .
+                                        escape_filter_value($username) .
+                                        ')' .
+                                        $filter .
                                         ')'
                                     );
 
     $RT::Logger->debug( "LDAP Search === ",
                         "Base:",
                         $base,
-                        "== Filter:", 
+                        "== Filter:",
                         $filter->as_string,
-                        "== Attrs:", 
+                        "== Attrs:",
                         join(',',@attrs));
 
     my $ldap_msg = $ldap->search(   base   => $base,
@@ -194,10 +196,10 @@ sub GetAuth {
                                     attrs  => \@attrs);
 
     unless ($ldap_msg->code == LDAP_SUCCESS || $ldap_msg->code == LDAP_PARTIAL_RESULTS) {
-        $RT::Logger->debug( "search for", 
-                            $filter->as_string, 
-                            "failed:", 
-                            ldap_error_name($ldap_msg->code), 
+        $RT::Logger->debug( "search for",
+                            $filter->as_string,
+                            "failed:",
+                            ldap_error_name($ldap_msg->code),
                             $ldap_msg->code);
         # Didn't even get a partial result - jump straight to the next external auth service
         return 0;
@@ -205,7 +207,7 @@ sub GetAuth {
 
     unless ($ldap_msg->count == 1) {
         $RT::Logger->info(  $service,
-                            "AUTH FAILED:", 
+                            "AUTH FAILED:",
                             $username,
                             "User not found or more than one user found");
         # We got no user, or too many users.. jump straight to the next external auth service
@@ -215,7 +217,7 @@ sub GetAuth {
     my $ldap_entry = $ldap_msg->first_entry;
     my $ldap_dn    = $ldap_entry->dn;
 
-    $RT::Logger->debug( "Found LDAP DN:", 
+    $RT::Logger->debug( "Found LDAP DN:",
                         $ldap_dn);
 
     # THIS bind determines success or failure on the password.
@@ -223,11 +225,11 @@ sub GetAuth {
 
     unless ($ldap_msg->code == LDAP_SUCCESS) {
         $RT::Logger->info(  $service,
-                            "AUTH FAILED", 
-                            $username, 
-                            "(can't bind:", 
-                            ldap_error_name($ldap_msg->code), 
-                            $ldap_msg->code, 
+                            "AUTH FAILED",
+                            $username,
+                            "(can't bind:",
+                            ldap_error_name($ldap_msg->code),
+                            $ldap_msg->code,
                             ")");
         # Could not bind to the LDAP server as the user we found with the password
         # we were given, therefore the password must be wrong so we fail and
@@ -250,29 +252,29 @@ sub GetAuth {
         # We only need the dn for the actual group since all we care about is existence
         @attrs  = qw(dn);
         $filter = Net::LDAP::Filter->new("(${group_attr}=" . escape_filter_value($group_val) . ")");
-        
+
         $RT::Logger->debug( "LDAP Search === ",
                             "Base:",
                             $group,
                             "== Scope:",
                             $group_scope,
-                            "== Filter:", 
+                            "== Filter:",
                             $filter->as_string,
-                            "== Attrs:", 
+                            "== Attrs:",
                             join(',',@attrs));
-        
+
         $ldap_msg = $ldap->search(  base   => $group,
                                     filter => $filter,
                                     attrs  => \@attrs,
                                     scope  => $group_scope);
 
         # And the user isn't a member:
-        unless ($ldap_msg->code == LDAP_SUCCESS || 
+        unless ($ldap_msg->code == LDAP_SUCCESS ||
                 $ldap_msg->code == LDAP_PARTIAL_RESULTS) {
-            $RT::Logger->critical(  "Search for", 
-                                    $filter->as_string, 
+            $RT::Logger->critical(  "Search for",
+                                    $filter->as_string,
                                     "failed:",
-                                    ldap_error_name($ldap_msg->code), 
+                                    ldap_error_name($ldap_msg->code),
                                     $ldap_msg->code);
 
             # Fail auth - jump to next external auth service
@@ -285,21 +287,21 @@ sub GetAuth {
                 $ldap_msg->count, "results"
             );
             $RT::Logger->info(  $service,
-                                "AUTH FAILED:", 
+                                "AUTH FAILED:",
                                 $username);
-                                
+
             # Fail auth - jump to next external auth service
             return 0;
         }
     }
-    
+
     # Any other checks you want to add? Add them here.
 
     # If we've survived to this point, we're good.
-    $RT::Logger->info(  (caller(0))[3], 
+    $RT::Logger->info(  (caller(0))[3],
                         "External Auth OK (",
                         $service,
-                        "):", 
+                        "):",
                         $username);
     return 1;
 
@@ -307,7 +309,7 @@ sub GetAuth {
 
 
 sub CanonicalizeUserInfo {
-    
+
     my ($service, $key, $value) = @_;
 
     my $found = 0;
@@ -316,8 +318,8 @@ sub CanonicalizeUserInfo {
                   RealName     => undef);
 
     # Load the config
-    my $config = $RT::ExternalSettings->{$service};
-   
+    my $config = RT->Config->Get('ExternalSettings')->{$service};
+
     # Figure out what's what
     my $base            = $config->{'base'};
     my $filter          = $config->{'filter'};
@@ -328,11 +330,11 @@ sub CanonicalizeUserInfo {
     # This is a bit confusing and probably broken. Something to revisit..
     my $filter_addition = ($key && $value) ? "(". $key . "=". escape_filter_value($value) .")" : "";
     if(defined($filter) && ($filter ne "()")) {
-        $filter = Net::LDAP::Filter->new(   "(&" . 
-                                            $filter . 
-                                            $filter_addition . 
+        $filter = Net::LDAP::Filter->new(   "(&" .
+                                            $filter .
+                                            $filter_addition .
                                             ")"
-                                        ); 
+                                        );
     } else {
         $RT::Logger->debug( "LDAP Filter invalid or not present.");
     }
@@ -347,7 +349,7 @@ sub CanonicalizeUserInfo {
     # Get a Net::LDAP object based on the config we provide
     my $ldap = _GetBoundLdapObj($config);
 
-    # Jump to the next external information service if we can't get one, 
+    # Jump to the next external information service if we can't get one,
     # errors should be logged by _GetBoundLdapObj so we don't have to.
     return ($found, %params) unless ($ldap);
 
@@ -355,9 +357,9 @@ sub CanonicalizeUserInfo {
     $RT::Logger->debug( "LDAP Search === ",
                         "Base:",
                         $base,
-                        "== Filter:", 
+                        "== Filter:",
                         $filter->as_string,
-                        "== Attrs:", 
+                        "== Attrs:",
                         join(',',@attrs));
 
     my $ldap_msg = $ldap->search(base   => $base,
@@ -365,28 +367,28 @@ sub CanonicalizeUserInfo {
                                  attrs  => \@attrs);
 
     # If we didn't get at LEAST a partial result, just die now.
-    if ($ldap_msg->code != LDAP_SUCCESS and 
+    if ($ldap_msg->code != LDAP_SUCCESS and
         $ldap_msg->code != LDAP_PARTIAL_RESULTS) {
         $RT::Logger->critical(  (caller(0))[3],
                                 ": Search for ",
                                 $filter->as_string,
                                 " failed: ",
-                                ldap_error_name($ldap_msg->code), 
+                                ldap_error_name($ldap_msg->code),
                                 $ldap_msg->code);
         # $found remains as 0
-        
+
         # Drop out to the next external information service
         $ldap_msg = $ldap->unbind();
         if ($ldap_msg->code != LDAP_SUCCESS) {
             $RT::Logger->critical(  (caller(0))[3],
-                                    ": Could not unbind: ", 
-                                    ldap_error_name($ldap_msg->code), 
+                                    ": Could not unbind: ",
+                                    ldap_error_name($ldap_msg->code),
                                     $ldap_msg->code);
         }
         undef $ldap;
         undef $ldap_msg;
         return ($found, %params);
-      
+
     } else {
         # If there's only one match, we're good; more than one and
         # we don't know which is the right one so we skip it.
@@ -399,7 +401,7 @@ sub CanonicalizeUserInfo {
                 if ($RT::LdapAttrMap and $RT::LdapAttrMap->{$key} eq 'dn') {
                     $params{$key} = $entry->dn();
                 } else {
-                    $params{$key} = 
+                    $params{$key} =
                       ($entry->get_value($config->{'attr_map'}->{$key}))[0];
                 }
             }
@@ -409,8 +411,8 @@ sub CanonicalizeUserInfo {
             $ldap_msg = $ldap->unbind();
             if ($ldap_msg->code != LDAP_SUCCESS) {
                 $RT::Logger->critical(  (caller(0))[3],
-                                        ": Could not unbind: ", 
-                                        ldap_error_name($ldap_msg->code), 
+                                        ": Could not unbind: ",
+                                        ldap_error_name($ldap_msg->code),
                                         $ldap_msg->code);
             }
             undef $ldap;
@@ -421,8 +423,8 @@ sub CanonicalizeUserInfo {
     $ldap_msg = $ldap->unbind();
     if ($ldap_msg->code != LDAP_SUCCESS) {
         $RT::Logger->critical(  (caller(0))[3],
-                                ": Could not unbind: ", 
-                                ldap_error_name($ldap_msg->code), 
+                                ": Could not unbind: ",
+                                ldap_error_name($ldap_msg->code),
                                 $ldap_msg->code);
     }
 
@@ -434,9 +436,9 @@ sub CanonicalizeUserInfo {
 
 sub UserExists {
     my ($username,$service) = @_;
-   $RT::Logger->debug("UserExists params:\nusername: $username , service: $service"); 
-    my $config              = $RT::ExternalSettings->{$service};
-    
+   $RT::Logger->debug("UserExists params:\nusername: $username , service: $service");
+    my $config              = RT->Config->Get('ExternalSettings')->{$service};
+
     my $base                = $config->{'base'};
     my $filter              = $config->{'filter'};
 
@@ -444,16 +446,16 @@ sub UserExists {
     # of parentheses is an invalid filter and will cause failure
     # This shouldn't matter since we are now using Net::LDAP::Filter below,
     # but there's no harm in doing this to be sure
-    if ($filter eq "()") { undef($filter) };
+    undef $filter if defined $filter and $filter eq "()";
 
     if (defined($config->{'attr_map'}->{'Name'})) {
         # Construct the complex filter
-        $filter = Net::LDAP::Filter->new(           '(&' . 
-                                                    $filter . 
-                                                    '(' . 
-                                                    $config->{'attr_map'}->{'Name'} . 
-                                                    '=' . 
-                                                    escape_filter_value($username) . 
+        $filter = Net::LDAP::Filter->new(           '(&' .
+                                                    $filter .
+                                                    '(' .
+                                                    $config->{'attr_map'}->{'Name'} .
+                                                    '=' .
+                                                    escape_filter_value($username) .
                                                     '))'
                                         );
     }
@@ -467,11 +469,11 @@ sub UserExists {
     $RT::Logger->debug( "LDAP Search === ",
                         "Base:",
                         $base,
-                        "== Filter:", 
-                        $filter->as_string,
-                        "== Attrs:", 
+                        "== Filter:",
+                        ($filter ? $filter->as_string : ''),
+                        "== Attrs:",
                         join(',',@attrs));
-    
+
     my $user_found = $ldap->search( base    => $base,
                                     filter  => $filter,
                                     attrs   => \@attrs);
@@ -482,8 +484,8 @@ sub UserExists {
                             $service,
                             ")",
                             $username,
-                            "User not found");   
-        return 0;  
+                            "User not found");
+        return 0;
     } elsif ($user_found->count > 1) {
         # If more than one result returned, die because we the username field should be unique!
         $RT::Logger->debug( "User Check Failed :: (",
@@ -494,7 +496,7 @@ sub UserExists {
         return 0;
     }
     undef $user_found;
-    
+
     # If we havent returned now, there must be a valid user.
     return 1;
 }
@@ -508,8 +510,8 @@ sub UserDisabled {
         $RT::Logger->debug("User (",$username,") doesn't exist! - Assuming not disabled for the purposes of disable checking");
         return 0;
     }
-    
-    my $config          = $RT::ExternalSettings->{$service};
+
+    my $config          = RT->Config->Get('ExternalSettings')->{$service};
     my $base            = $config->{'base'};
     my $filter          = $config->{'filter'};
     my $d_filter        = $config->{'d_filter'};
@@ -519,8 +521,8 @@ sub UserDisabled {
     # of parentheses is an invalid filter and will cause failure
     # This shouldn't matter since we are now using Net::LDAP::Filter below,
     # but there's no harm in doing this to be sure
-    if ($filter eq "()") { undef($filter) };
-    if ($d_filter eq "()") { undef($d_filter) };
+    undef $filter   if defined $filter   and $filter eq "()";
+    undef $d_filter if defined $d_filter and $d_filter eq "()";
 
     unless ($d_filter) {
         # If we don't know how to check for disabled users, consider them all enabled.
@@ -532,13 +534,13 @@ sub UserDisabled {
 
     if (defined($config->{'attr_map'}->{'Name'})) {
         # Construct the complex filter
-        $search_filter = Net::LDAP::Filter->new(   '(&' . 
-                                                    $filter . 
-                                                    $d_filter . 
-                                                    '(' . 
-                                                    $config->{'attr_map'}->{'Name'} . 
-                                                    '=' . 
-                                                    escape_filter_value($username) . 
+        $search_filter = Net::LDAP::Filter->new(   '(&' .
+                                                    $filter .
+                                                    $d_filter .
+                                                    '(' .
+                                                    $config->{'attr_map'}->{'Name'} .
+                                                    '=' .
+                                                    escape_filter_value($username) .
                                                     '))'
                                                 );
     } else {
@@ -548,28 +550,28 @@ sub UserDisabled {
                             $username,
                             ") so I'm just going to assume the user is not disabled");
         return 0;
-        
+
     }
 
     my $ldap = _GetBoundLdapObj($config);
     next unless $ldap;
 
-    # We only need the UID for confirmation now, 
+    # We only need the UID for confirmation now,
     # the other information would waste time and bandwidth
-    my @attrs = ('uid'); 
-    
+    my @attrs = ('uid');
+
     $RT::Logger->debug( "LDAP Search === ",
                         "Base:",
                         $base,
-                        "== Filter:", 
-                        $search_filter->as_string,
-                        "== Attrs:", 
+                        "== Filter:",
+                        ($search_filter ? $search_filter->as_string : ''),
+                        "== Attrs:",
                         join(',',@attrs));
-          
-    my $disabled_users = $ldap->search(base   => $base, 
-                                       filter => $search_filter, 
+
+    my $disabled_users = $ldap->search(base   => $base,
+                                       filter => $search_filter,
                                        attrs  => \@attrs);
-    # If ANY results are returned, 
+    # If ANY results are returned,
     # we are going to assume the user should be disabled
     if ($disabled_users->count) {
         undef $disabled_users;
@@ -591,11 +593,11 @@ sub _GetBoundLdapObj {
     my $ldap_user       = $config->{'user'};
     my $ldap_pass       = $config->{'pass'};
     my $ldap_tls        = $config->{'tls'};
-    my $ldap_ssl_ver    = $config->{'ssl_version'};
+    $ldap_tls = $ldap_tls ? {} : undef unless ref $ldap_tls;
     my $ldap_args       = $config->{'net_ldap_args'};
-    
+
     my $ldap = new Net::LDAP($ldap_server, @$ldap_args);
-    
+
     unless ($ldap) {
         $RT::Logger->critical(  (caller(0))[3],
                                 ": Cannot connect to",
@@ -604,12 +606,10 @@ sub _GetBoundLdapObj {
     }
 
     if ($ldap_tls) {
-        require Net::SSLeay;
-        $Net::SSLeay::ssl_version = $ldap_ssl_ver;
         # Thanks to David Narayan for the fault tolerance bits
-        eval { $ldap->start_tls; };
+        eval { $ldap->start_tls( %{$ldap_tls} ); };
         if ($@) {
-            $RT::Logger->critical(  (caller(0))[3], 
+            $RT::Logger->critical(  (caller(0))[3],
                                     "Can't start TLS: ",
                                     $@);
             return;
@@ -628,9 +628,9 @@ sub _GetBoundLdapObj {
     }
 
     unless ($msg->code == LDAP_SUCCESS) {
-        $RT::Logger->critical(  (caller(0))[3], 
-                                "Can't bind:", 
-                                ldap_error_name($msg->code), 
+        $RT::Logger->critical(  (caller(0))[3],
+                                "Can't bind:",
+                                ldap_error_name($msg->code),
                                 $msg->code);
         return undef;
     } else {
